@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie qw( :all );
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use App::CISetup::Types qw( Bool File Str );
 use File::pushd;
@@ -214,6 +214,7 @@ sub _update_perl_matrix {
     }
 
     $travis->{matrix} = {
+        fast_finish    => 1,
         include        => \@include,
         allow_failures => \@allow_failures,
     };
@@ -342,6 +343,7 @@ my @BlocksOrder = qw(
     cache
     solution
     matrix
+    fast_finish
     env
     branches
     services
